@@ -2,10 +2,6 @@ from .clusters import ClustersClient
 from .dataset_client import DatasetsClient
 from .dataset_tag_client import DatasetTagsClient
 from .dataset_version_client import DatasetVersionsClient
-from .deployment_client import DeploymentsClient
-from .experiment_client import ExperimentsClient
-from .hyperparameter_client import HyperparameterJobsClient
-from .job_client import JobsClient
 from .machine_types_client import MachineTypesClient
 from .machines_client import MachinesClient
 from .model_client import ModelsClient
@@ -13,7 +9,6 @@ from .notebook_client import NotebooksClient
 from .project_client import ProjectsClient
 from .secret_client import SecretsClient
 from .storage_provider_client import StorageProvidersClient
-from .tensorboards_client import TensorboardClient
 from .workflow_client import WorkflowsClient
 
 from .sdk_client import SdkClient
