@@ -18,15 +18,12 @@ _DEFAULT_WEB_URL = "https://console.paperspace.com"
 _DEFAULT_API_HOST = "https://api.paperspace.com/graphql"
 _DEFAULT_CONFIG_HOST = "https://api.paperspace.io"
 _DEFAULT_CONFIG_LOG_HOST = "https://logs.paperspace.io"
-_DEFAULT_CONFIG_EXPERIMENTS_HOST = "https://services.paperspace.io/experiments/v1/"
-_DEFAULT_CONFIG_EXPERIMENTS_HOST_V2 = "https://services.paperspace.io/experiments/v2/"
 _DEFAULT_CONFIG_SERVICE_HOST = "https://services.paperspace.io"
 _DEFAULT_CONFIG_DIR_PATH = "~/.paperspace"
 _DEFAULT_CONFIG_FILE_NAME = os.path.expanduser("config.json")
 _DEFAULT_HELP_HEADERS_COLOR = "yellow"
 _DEFAULT_HELP_OPTIONS_COLOR = "green"
 _DEFAULT_USE_CONSOLE_COLORS = True
-_DEFAULT_USE_LEGACY_DEPLOYMENTS = False
 
 
 def get_help_colors_dict(use_colors, help_headers_color, help_options_color):
@@ -45,19 +42,24 @@ class config(object):
 
     WEB_URL = os.environ.get("PAPERSPACE_WEB_URL", _DEFAULT_WEB_URL)
     API_HOST = os.environ.get("PAPERSPACE_API_HOST", _DEFAULT_API_HOST)
-    USE_LEGACY_DEPLOYMENTS = os.environ.get("USE_LEGACY_DEPLOYMENTS", _DEFAULT_USE_LEGACY_DEPLOYMENTS)
-    CONFIG_HOST = os.environ.get("PAPERSPACE_CONFIG_HOST", _DEFAULT_CONFIG_HOST)
-    CONFIG_LOG_HOST = os.environ.get("PAPERSPACE_CONFIG_LOG_HOST", _DEFAULT_CONFIG_LOG_HOST)
-    CONFIG_EXPERIMENTS_HOST = os.environ.get("PAPERSPACE_CONFIG_EXPERIMENTS_HOST", _DEFAULT_CONFIG_EXPERIMENTS_HOST)
-    CONFIG_EXPERIMENTS_HOST_V2 = os.environ.get("PAPERSPACE_CONFIG_EXPERIMENTS_HOST_V2",
-                                                _DEFAULT_CONFIG_EXPERIMENTS_HOST_V2)
-    CONFIG_SERVICE_HOST = os.environ.get("PAPERSPACE_CONFIG_SERVICE_HOST", _DEFAULT_CONFIG_SERVICE_HOST)
-    CONFIG_DIR_PATH = os.path.expanduser(os.environ.get("PAPERSPACE_CONFIG_PATH", _DEFAULT_CONFIG_DIR_PATH))
-    CONFIG_FILE_NAME = os.environ.get("PAPERSPACE_CONFIG_FILE_NAME", _DEFAULT_CONFIG_FILE_NAME)
-    PAPERSPACE_API_KEY = os.environ.get("PAPERSPACE_API_KEY", get_api_key(CONFIG_DIR_PATH, CONFIG_FILE_NAME))
+    CONFIG_HOST = os.environ.get(
+        "PAPERSPACE_CONFIG_HOST", _DEFAULT_CONFIG_HOST)
+    CONFIG_LOG_HOST = os.environ.get(
+        "PAPERSPACE_CONFIG_LOG_HOST", _DEFAULT_CONFIG_LOG_HOST)
+    CONFIG_SERVICE_HOST = os.environ.get(
+        "PAPERSPACE_CONFIG_SERVICE_HOST", _DEFAULT_CONFIG_SERVICE_HOST)
+    CONFIG_DIR_PATH = os.path.expanduser(os.environ.get(
+        "PAPERSPACE_CONFIG_PATH", _DEFAULT_CONFIG_DIR_PATH))
+    CONFIG_FILE_NAME = os.environ.get(
+        "PAPERSPACE_CONFIG_FILE_NAME", _DEFAULT_CONFIG_FILE_NAME)
+    PAPERSPACE_API_KEY = os.environ.get(
+        "PAPERSPACE_API_KEY", get_api_key(CONFIG_DIR_PATH, CONFIG_FILE_NAME))
 
-    HELP_HEADERS_COLOR = os.environ.get("PAPERSPACE_HELP_HEADERS_COLOR", _DEFAULT_HELP_HEADERS_COLOR)
-    HELP_OPTIONS_COLOR = os.environ.get("PAPERSPACE_HELP_OPTIONS_COLOR", _DEFAULT_HELP_OPTIONS_COLOR)
+    HELP_HEADERS_COLOR = os.environ.get(
+        "PAPERSPACE_HELP_HEADERS_COLOR", _DEFAULT_HELP_HEADERS_COLOR)
+    HELP_OPTIONS_COLOR = os.environ.get(
+        "PAPERSPACE_HELP_OPTIONS_COLOR", _DEFAULT_HELP_OPTIONS_COLOR)
     USE_CONSOLE_COLORS = os.environ.get("PAPERSPACE_USE_CONSOLE_COLORS",
                                         _DEFAULT_USE_CONSOLE_COLORS) in (True, "true", "1")
-    HELP_COLORS_DICT = get_help_colors_dict(USE_CONSOLE_COLORS, HELP_HEADERS_COLOR, HELP_OPTIONS_COLOR)
+    HELP_COLORS_DICT = get_help_colors_dict(
+        USE_CONSOLE_COLORS, HELP_HEADERS_COLOR, HELP_OPTIONS_COLOR)
